Struct govern::ProposalInstruction
source · [−]pub struct ProposalInstruction {
pub program_id: Pubkey,
pub keys: Vec<ProposalAccountMeta>,
pub data: Vec<u8>,
}Expand description
Instruction.
Fields
program_id: PubkeyPubkey of the instruction processor that executes this instruction
keys: Vec<ProposalAccountMeta>Metadata for what accounts should be passed to the instruction processor
data: Vec<u8>Opaque data passed to the instruction processor
Implementations
Space that a ProposalInstruction takes up.